@@ -52,7 +52,7 @@ namespace trng {
     
     // Parameter and status classes
     class status_type;
-
+    
     class status_type {
       result_type r[utility::ceil2<D>::result];
       unsigned int index;
@@ -121,6 +121,10 @@ namespace trng {
       seed();
     }
     
+    explicit lagfib4xor(unsigned long s) : S() {
+      seed(s);
+    }
+    
     template<typename gen>
     explicit lagfib4xor(gen &g) : S() {
       seed(g);
